@@ -48,24 +48,24 @@ class Issue:
 global_functions = create_dictionary(data={i["name"]: i for i in
                     [{"name": "cos",
                       "full_name": "math.cos",
-                      "kwargs": None},
+                      "kwargs": {}},
                      {"name": "sin",
                       "full_name": "math.sin",
-                      "kwargs": None},
+                      "kwargs": {}},
                      {"name": "InterfaceType",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.get_interface_type",
-                      "kwargs": None,
+                      "kwargs": {},
                       "special_kwargs": {"PartialRetrievalDictionary": "prd"}},
                      {"name": "NISName",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.get_nis_name",
-                      "kwargs": None},
+                      "kwargs": {}},
                      {"name": "Processor",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.get_processor",
-                      "kwargs": None,
+                      "kwargs": {},
                       "special_kwargs": {"PartialRetrievalDictionary": "prd"}},
                      {"name": "LCIAMethod",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.lcia_method",
-                      "kwargs": None,
+                      "kwargs": {},
                       "special_kwargs": {"IndicatorState": "state",
                                          "LCIAMethods": "lcia_methods"}},
                      ]
@@ -74,32 +74,32 @@ global_functions = create_dictionary(data={i["name"]: i for i in
 global_functions_extended = create_dictionary(data={i["name"]: i for i in
                     [{"name": "sum",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.aggregator_sum",
-                      "kwargs": None,
+                      "kwargs": {},
                       "special_kwargs": {"ProcessorsMap": "processors_map", "ProcessorsDOM": "processors_dom",
                                          "DataFrameGroup": "df_group", "IndicatorsDataFrameGroup": "df_indicators_group"}},
                      {"name": "avg",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.aggregator_avg",
-                      "kwargs": None,
+                      "kwargs": {},
                       "special_kwargs": {"ProcessorsMap": "processors_map", "ProcessorsDOM": "processors_dom",
                                          "DataFrameGroup": "df_group", "IndicatorsDataFrameGroup": "df_indicators_group"}},
                      {"name": "max",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.aggregator_max",
-                      "kwargs": None,
+                      "kwargs": {},
                       "special_kwargs": {"ProcessorsMap": "processors_map", "ProcessorsDOM": "processors_dom",
                                          "DataFrameGroup": "df_group", "IndicatorsDataFrameGroup": "df_indicators_group"}},
                      {"name": "min",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.aggregator_min",
-                      "kwargs": None,
+                      "kwargs": {},
                       "special_kwargs": {"ProcessorsMap": "processors_map", "ProcessorsDOM": "processors_dom",
                                          "DataFrameGroup": "df_group", "IndicatorsDataFrameGroup": "df_indicators_group"}},
                      {"name": "count",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.aggregator_count",
-                      "kwargs": None,
+                      "kwargs": {},
                       "special_kwargs": {"ProcessorsMap": "processors_map", "ProcessorsDOM": "processors_dom",
                                          "DataFrameGroup": "df_group", "IndicatorsDataFrameGroup": "df_indicators_group"}},
                      {"name": "nancount",
                       "full_name": "nexinfosys.command_generators.parser_ast_evaluators.aggregator_nan_count",
-                      "kwargs": None,
+                      "kwargs": {},
                       "special_kwargs": {"ProcessorsMap": "processors_map", "ProcessorsDOM": "processors_dom",
                                          "DataFrameGroup": "df_group", "IndicatorsDataFrameGroup": "df_indicators_group"}},
                      ]
