@@ -15,9 +15,9 @@ from nexinfosys import case_sensitive, ureg
 from pyparsing import quotedString
 
 from nexinfosys.model_services import State
-from nexinfosys.command_generators import global_functions, IType, Issue, IssueLocation
+from nexinfosys.command_generators import global_functions, IType, Issue, IssueLocation, parser_field_parsers
 from nexinfosys.command_generators.parser_field_parsers import string_to_ast, arith_boolean_expression, key_value_list, \
-    simple_ident, expression_with_parameters, number_interval
+    simple_ident, expression_with_parameters, number_interval, arith_boolean_expression_with_less_tokens
 from nexinfosys.common.helper import create_dictionary, PartialRetrievalDictionary, strcmp, is_float
 from nexinfosys.models.musiasem_concepts import ExternalDataset, FactorType, Processor, Hierarchy
 
@@ -395,24 +395,22 @@ def ast_evaluator(exp: Dict, state: State, obj, issue_lst, evaluation_type="nume
                         mod_name, func_name = _f["full_name"].rsplit('.', 1)
                         mod = importlib.import_module(mod_name)
                         func = getattr(mod, func_name)
-                        if _f["kwargs"]:
-                            kwargs.update(_f["kwargs"])
-                        if _f["special_kwargs"]:
-                            for sp_kwarg, name in _f["special_kwargs"].items():
-                                if sp_kwarg == "PartialRetrievalDictionary":
-                                    kwargs[name] = state.get("_glb_idx")
-                                elif sp_kwarg == "ProcessorsDOM":
-                                    kwargs[name] = state.get("_processors_dom")
-                                elif sp_kwarg == "ProcessorsMap":
-                                    kwargs[name] = state.get("_processors_map")
-                                elif sp_kwarg == "DataFrameGroup":
-                                    kwargs[name] = state.get("_df_group")
-                                elif sp_kwarg == "IndicatorsDataFrameGroup":
-                                    kwargs[name] = state.get("_df_indicators_group")
-                                elif sp_kwarg == "IndicatorState":
-                                    kwargs[name] = state
-                                elif sp_kwarg == "LCIAMethods":
-                                    kwargs[name] = state.get("_lcia_methods")
+                        kwargs.update(_f["kwargs"])
+                        for sp_kwarg, name in _f.get("special_kwargs", {}).items():
+                            if sp_kwarg == "PartialRetrievalDictionary":
+                                kwargs[name] = state.get("_glb_idx")
+                            elif sp_kwarg == "ProcessorsDOM":
+                                kwargs[name] = state.get("_processors_dom")
+                            elif sp_kwarg == "ProcessorsMap":
+                                kwargs[name] = state.get("_processors_map")
+                            elif sp_kwarg == "DataFrameGroup":
+                                kwargs[name] = state.get("_df_group")
+                            elif sp_kwarg == "IndicatorsDataFrameGroup":
+                                kwargs[name] = state.get("_df_indicators_group")
+                            elif sp_kwarg == "IndicatorState":
+                                kwargs[name] = state
+                            elif sp_kwarg == "LCIAMethods":
+                                kwargs[name] = state.get("_lcia_methods")
 
                         # CALL FUNCTION!!
                         try:
@@ -700,32 +698,46 @@ def dictionary_from_key_value_list(kvl, state: State = None):
     :except If syntactic problems occur
     :return: A dictionary
     """
-    pairs = kvl.split(",")
-    d = create_dictionary()
-    for p in pairs:
-        k, v = p.split("=", maxsplit=1)
-        if not k:
-            raise Exception(
-                "Each key-value pair must be separated by '=' and key has to be defined, value can be empty: " + kvl)
-        else:
-            try:
-                k = k.strip()
-                v = v.strip()
-                string_to_ast(simple_ident, k)
-                try:
-                    # Simplest: string
-                    string_to_ast(quotedString, v)
-                    v = v[1:-1]
-                except:
-                    issues = []
-                    ast = string_to_ast(expression_with_parameters, v)
-                    res, unres = ast_evaluator(ast, state, None, issues)
-                    if len(unres) == 0:
-                        v = res
+    try:
+        ast = parser_field_parsers.string_to_ast(key_value_list, kvl)
+    except:
+        raise Exception(f"Could not parse key-value list: {key_value_list}")
 
-                d[k] = v
-            except:
-                raise Exception("Key must be a string: " + k + " in key-value list: " + kvl)
+    d = create_dictionary()
+    for k, v in ast["parts"].items():
+        issues = []
+        res, unres = ast_evaluator(v, state, None, issues)
+        if len(unres) == 0:
+            v = res
+            d[k] = v
+        else:
+            raise Exception(f"Could not evaluate key '{k}' in key-value list. Value: {v}")
+
+    # pairs = kvl.split(",")
+    # for p in pairs:
+    #     k, v = p.split("=", maxsplit=1)
+    #     if not k:
+    #         raise Exception(
+    #             "Each key-value pair must be separated by '=' and key has to be defined, value can be empty: " + kvl)
+    #     else:
+    #         try:
+    #             k = k.strip()
+    #             v = v.strip()
+    #             string_to_ast(simple_ident, k)
+    #             try:
+    #                 # Simplest: string
+    #                 string_to_ast(quotedString, v)
+    #                 v = v[1:-1]
+    #             except:
+    #                 issues = []
+    #                 ast = string_to_ast(expression_with_parameters, v)
+    #                 res, unres = ast_evaluator(ast, state, None, issues)
+    #                 if len(unres) == 0:
+    #                     v = res
+    #
+    #             d[k] = v
+    #         except:
+    #             raise Exception("Key must be a string: " + k + " in key-value list: " + kvl)
     return d
 
 
@@ -784,6 +796,14 @@ if __name__ == '__main__':
     from nexinfosys.model_services import State
     from dotted.collection import DottedDict
 
+    ast = string_to_ast(arith_boolean_expression_with_less_tokens, "200 < capacity_factor and capacity_factor < 400")
+    ast2 = string_to_ast(arith_boolean_expression, "200 < capacity_factor and capacity_factor < 400")
+    s = State()
+    s.set("capacity_factor", 300)
+    issues = []
+    res2, unres2 = ast_evaluator(ast2, s, None, issues)
+    res, unres = ast_evaluator(ast, s, None, issues)
+
     issues = []
     s = State()
     ex = "level =”N - 1”, farm_type =”GH”, efficiency = 0.3"
